Skip to contents

For each segment in the data, computes the MAF likelihood across all major/minor allele combinations for given mutation multiplicity (\(\mu\)) and tumor purity (\(\rho\)).

Usage

Callikelihood(mu, rho, data, sigma_C, lambda, gamma, epsilon)

Arguments

mu

Numeric. Diploid coverage scale factor (e.g. A value of 1 indicates that the segment mean from GATK does not require adjustment. Additionally, the pseudo-diploid coverage is set to 100.).

rho

Numeric. Tumor purity (fraction between 0 and 1).

data

Data frame or tibble. Must include columns: Segcov, MAF, index, Tag, and k.

sigma_C

Numeric. Parameter for segment likelihood (passed to CalSegmentLikelihood).

lambda

Numeric. Exponential decay parameter for the prior.

gamma

Numeric. Weight for the prior in the likelihood calculation.

epsilon

Numeric. Small value to avoid log(0) and zero parameters in beta.

Value

A data frame with the segment likelihoods and all columns from CalSegmentLikelihood, plus index and Tag.

Details

For each segment, calls CalSegmentLikelihood and filters out combinations with ccf > 1.2. If there is only one combination and both major and minor are zero, sets MAF_likelihood to 1.