Skip to contents

Estimates tumor purity by fitting coverage and MAF segmentation data across a range of purity values, selecting the purity that best matches integer copy number models.

Usage

EstimatePurityCov(seg, gender)

Arguments

seg

A data frame or tibble of segment data, with columns: Chromosome, Segment_Mean, MAF, MAF_gmm_G, MAF_Probes, MAF_gmm_weight, size, etc.

gender

Gender male or femal.

Value

A list with elements:

dis_df

Data frame of model fit statistics for each purity.

Final_model

List with Final_mu and Final_rho (the selected purity).

min_dis

Minimum distance to integer copy numbers.

seg_call

Segment calls for the selected purity.

Model_source

String, always "Coverage".

Details

This function fits models for a sequence of purity values, applies segment correction and calling, and selects the purity with the best fit to integer copy number.