Skip to contents

For a given (mu, rho) combination, joins the segment call results to the segment metadata and returns the final calls.

Usage

ExtractCall(df, max_L_mu, max_L_rho, seg)

Arguments

df

Data frame or tibble. Contains segment call results, including columns mu, rho, and index.

max_L_mu

Numeric. The selected value of mutation multiplicity (mu).

max_L_rho

Numeric. The selected value of tumor purity (rho).

seg

Data frame or tibble. Segment metadata, must include column index.

Value

A data frame or tibble with the final calls for the given (mu, rho) model, joined to segment metadata.

Examples

# ExtractCall(df, max_L_mu = 1, max_L_rho = 0.7, seg)