Skip to contents

Generates all valid combinations of major and minor allele copy numbers that sum to the specified total copy number, with the constraint that major >= minor.

Usage

GenerateCombinations(CN)

Arguments

CN

Integer. The total copy number.

Value

A data frame with columns:

major

Major allele copy number.

minor

Minor allele copy number.

CN

Sum of major and minor (equals input CN).

Examples

GenerateCombinations(3)
#>   major minor CN
#> 4     3     0  3
#> 7     2     1  3