Skip to contents

Filters AI (allelic imbalance) bins to include only those overlapping whitelisted regions.

Usage

KeepWhitelistAI(rounded_ai, whitelist)

Arguments

rounded_ai

Data frame or tibble. Rounded AI data, must include columns contig, start, and stop.

whitelist

Data frame or tibble. Whitelist regions, must include columns seqnames, start, and end.

Value

A data frame of AI bins that overlap whitelisted regions.

Examples

# KeepWhitelistAI(rounded_ai, whitelist)