Skip to contents

Filters smoothed coverage bins to include only those overlapping whitelisted regions.

Usage

KeepWhitelistCov(smooth_cov, whitelist, gender)

Arguments

smooth_cov

Data frame or tibble. Smoothed coverage data, must include columns CONTIG, bin_start, and bin_end.

whitelist

Data frame or tibble. Whitelist regions, must include columns chrom, start, and end.

gender

Character. femle or male.

Value

A data frame of smoothed coverage bins that overlap whitelisted regions.

Examples

# KeepWhitelistCov(smooth_cov, whitelist)