Skip to contents

Determines whether two adjacent copy number segments should be merged based on the difference in their segment means and whether their calls are identical.

Usage

MergeSegCheck(cur_row, next_row, mergecov)

Arguments

cur_row

A data frame row (list or tibble row) representing the current segment. Must have Segment_Mean and Call.

next_row

A data frame row (list or tibble row) representing the next segment. Must have Segment_Mean and Call.

mergecov

Numeric threshold for segment mean difference

Value

Logical value: TRUE if the two segments should be merged, FALSE otherwise.