Skip to contents

Reads multiple allelic imbalance (AI) files from a panel of normal (PoN), processes and combines the results into a single data frame.

Usage

ReadPonAI(ai_pon_file, aitype, minsnpcov, gender)

Arguments

ai_pon_file

Character. Path to a text file listing the paths to all PoN AI files (one file path per line).

aitype

Character. Type of AI input file. Passed to ReadAI() (e.g., "gatk", "dragen", "other").

minsnpcov

Integer. Minimum SNP coverage to include a site in the AI calculation. Passed to ReadAI().

gender

Character. Sample gender, either "female" or "male". This value is passed to ReadAI().

Value

A data frame combining all AI data from the PoN files.

Details

Each file path listed in ai_pon_file is read and processed using ReadAI(), with the resulting data frames combined by row.