Skip to contents

For each combination of purity and scale factor in purity_sf, computes the segment likelihoods for all segments in data using the specified model parameters.

Usage

RunCallikelihood(
  purity_sf,
  data,
  sigma_C,
  lambda = 1,
  gamma = 1,
  epsilon = 0.01
)

Arguments

purity_sf

Data frame or tibble. Grid of purity and scale factor values to evaluate; must include columns mu and rho.

data

Data frame or tibble. Segment data (see Callikelihood for required columns).

sigma_C

Numeric. Parameter for segment likelihood (passed to Callikelihood).

Value

A data frame with all likelihoods for each segment and each (mu, rho) combination, with NA minor alleles removed and NA ccf values set to 1.

Examples

# RunCallikelihood(purity_sf, data, sigma_C = 0.1, lambda = 1, gamma = 1, epsilon = 0.01)