If the length of the input vector is greater than 30, returns a vector of up to 30 values sampled according to the observed frequency of each unique value. Otherwise, returns the vector unchanged.
If the length of the input vector is greater than 30, returns a vector of up to 30 values sampled according to the observed frequency of each unique value. Otherwise, returns the vector unchanged.