Skip to contents

Assigns a quality tag ("PASS" or "FAILED") to a segment based on the maf GMM weight and probe count thresholds.

Usage

AddQualTag(Chromosome, MAF_gmm_weight, MAF_Probes, MAF_gmm_G, snpmin)

Arguments

Chromosome

Character.

MAF_gmm_weight

Numeric. The mixture weight of the most prominent maf GMM cluster.

MAF_Probes

Integer. The number of nonzero maf probes in the segment.

MAF_gmm_G

Integer. Number of maf GMM clusters.

snpmin

Integer. The minimum nonzero SNP count.

Value

Character. "PASS" if the segment passes quality checks, "FAILED" otherwise.

Details

A segment is marked as "PASS" if the maf GMM weight is at least 0.35 and the probe count is at least twice the minimum SNP count (snpmin). Otherwise, it is marked as "FAILED".

Examples

AddQualTag(Chromosome = "1", MAF_gmm_weight = 0.4, MAF_Probes = 20, MAF_gmm_G = 2, snpmin = 7)
#> [1] "PASS"
AddQualTag(Chromosome = "X", MAF_gmm_weight = 0.2, MAF_Probes = 10, MAF_gmm_G = 1, snpmin = 7)
#> [1] "Exclude"