Calculate CNF based on purity and diploid coverage size factor
Source:R/CNVplot.R
CRCorrectPurity.RdAdjusts the log2 copy ratio and computes the copy number fraction (CNF) for each region, given sample purity and scale factor.
Value
The coverage data frame or tibble with additional columns Segcov, updated LOG2_COPY_RATIO, and CNF.