Cluster and Select the Best Models Based on Likelihood and Copy Number Distance
Source:R/Modeling.R
ClusterModels.RdClusters models by total likelihood, diploid and nondiploid distance to integer copy number, and selects the best (mu, rho) model.
Value
A list with:
- Final_mu
Best model's mutation multiplicity.
- Final_rho
Best model's tumor purity.
- total_distance_to_integer
Total distance to integer copy number for the best model.
- total_likelihood
Total log-likelihood for the best model.
- models
The full, clustered, and sorted model data frame.