Find the "Elbow" Point in a Ranked Vector (Tier 1 Model Selection)
Source:R/Modeling.R
FindTier1Models.RdIdentifies the first major drop ("elbow") in a sorted vector of values, using a smoothed difference approach.

R/Modeling.R
FindTier1Models.RdIdentifies the first major drop ("elbow") in a sorted vector of values, using a smoothed difference approach.