Returns a cytoband-based annotation string for a CNV segment, based on the segment's position and its proximity to p and q arm detectable region boundaries.
Usage
GenerateISCN(
chrom,
Start,
End,
CNF,
CN,
p_chromStart,
p_chromEnd,
p_first_name,
p_last_name,
q_chromStart,
q_chromEnd,
q_first_name,
q_last_name,
p_gap_to_tel,
p_gap_to_cen,
q_gap_to_tel,
q_gap_to_cen,
cytoband
)Arguments
- chrom
Character. Chromosome name.
- Start,
End Numeric. Segment start and end positions (base pairs).
- CNF
Numeric. Fractional copy number.
- CN
Integer. Integer copy number.
- p_chromStart,
p_chromEnd Numeric. p-arm detectable region start and end positions.
- p_first_name,
p_last_name Character. Cytoband names for the p-arm start and end.
- q_chromStart,
q_chromEnd Numeric. q-arm detectable region start and end positions.
- q_first_name,
q_last_name Character. Cytoband names for the q-arm start and end.
- p_gap_to_tel,
p_gap_to_cen, q_gap_to_tel, q_gap_to_cen Numeric. Gaps between segment and detectable region boundaries (from
CalculateGaps).- cytoband
Data frame. Cytoband annotation table.
Details
The function determines the annotation as follows:
If the segment start and end are in the same cytoband, returns a single-band range.
If the segment spans multiple cytobands, returns the range from start to end cytoband.
If the segment is close to both p-arm telomere and centromere (or at the p-arm boundaries), returns a p-arm event only.
If the segment is close to both q-arm centromere and telomere (or at the q-arm boundaries), returns a q-arm event only (or chromosome-level event for acrocentric chromosomes).
If the segment is close to both p-arm and q-arm telomeres (or covers the whole chromosome), returns a chromosome-level event. The gap size smaller than 5MB are defined as "close".
For acrocentric chromosomes, only q-arm boundaries are considered.
The annotation string is determined by the size of the gaps between the segment and p/q arm detectable region boundaries and the cytoband names at the segment start and end. Events are reported as a cytoband range, p-arm only, q-arm only, or chromosome-level event.